@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 96 $
+# Revision: $Rev: 99 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -239,13 +239,16 @@ class ListViewRecord(QListView):
                 return
             
             # rollover
-            if (not self.wrappedSearch and (self.itemPos(nextItem) < self.itemPos(currItem))):
+            if (not self.wrappedSearch and
+                ((self.itemPos(nextItem) < self.itemPos(currItem)) or (currItem == self.lastItem()))):
                 self.setCurrentItem(currItem)
                 self.wrappedSearch = True
                 self.emit(PYSIGNAL("incSearchTextChanged"), ("End of list: wrap over?",))
                 QApplication.beep()
                 return
-            self.wrappedSearch = False
+            elif (self.wrappedSearch):
+                self.wrappedSearch = False
+                self.setCurrentItem(self.firstChild())
 
         else:
             self.incSearch += unicode(e.text())
