@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 93 $
+# Revision: $Rev: 100 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -35,7 +35,7 @@ from pprint import pformat
 CONFIG_TEXT = """\
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 93 $
+# Revision: $Rev: 100 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -194,6 +194,14 @@ systemEncoding = %(systemEncoding)s
 recordStoreOrderRandom = %(recordStoreOrderRandom)s
 
 
+# Pictures may be saved embedded or linked to files on the filesystem.
+# Setting deepcopyOnCopy to True will cause copy&paste to create a
+# duplicate picture in the filesystem. The value False will just copy
+# the link and reference the picture of the source record.
+# Default: True
+
+deepcopyOnCopy = %(deepcopyOnCopy)s
+
 # mediaInfo is the class name of the library to use when scanning 
 # a movie for its properties, such as video bitrate, length, size, etc.
 # To set this value correctly you need to import the module, as in
@@ -345,7 +353,8 @@ defaultScript = %(defaultScript)s
 class _Settings0(dict):
     """defines first element in configuration chain"""
     default = {
-        'logLevel': {'default'               : logging.DEBUG,
+        'logLevel': {'<none>'                : logging.DEBUG,
+                     'default'               : logging.DEBUG,
                      '__main__'              : logging.DEBUG,
                      'AbstractFile'          : logging.DEBUG,
                      'AMCFile33'             : logging.DEBUG,
@@ -420,13 +429,15 @@ class _Settings0(dict):
         'systemEncoding': 'latin1',
         
         'recordStoreOrderRandom': False,
+
+        'deepcopyOnCopy': True,
         
         'mediaInfo': None,
         'autoMountPoint': None,
         'ejectOnUnmount': True,
         'autoScanAutoMountOnNew': True,
         'autoScanOnNew': False,
-        'autoScriptOnNew': True,
+        'autoScriptOnNew': False,
         
         'embeddedImage': False,
         'imageFormat': 'JPEG',
@@ -485,7 +496,7 @@ class _Settings0(dict):
                     'zeroPrefix_patch', 'scripts', 'defaultScript', 'autoMountPoint',
                     'ejectOnUnmount', 'defaultHistory', 'addHistoryFromRecords',
                     'recordDefault', 'autoScanAutoMountOnNew', 'autoScanOnNew',
-                    'autoScriptOnNew']:
+                    'autoScriptOnNew', 'deepcopyOnCopy']:
             defs[key] = pformat(self[key])
 
         # class instance 
@@ -599,7 +610,8 @@ class _Pref(dict):
                     'sortColumn', 'zeroPrefix_patch', 'scripts',
                     'defaultScript', 'autoMountPoint', 'ejectOnUnmount',
                     'defaultHistory', 'addHistoryFromRecords', 'recordDefault',
-                    'autoScanAutoMountOnNew', 'autoScanOnNew', 'autoScriptOnNew']:
+                    'autoScanAutoMountOnNew', 'autoScanOnNew', 'autoScriptOnNew',
+                    'deepcopyOnCopy']:
             self[key] = deepcopy(pref[key])
 
         # debug info on a per-class basis
