@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 97 $
+# Revision: $Rev: 101 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -62,7 +62,7 @@ log.addHandler(hdlr)
 log.setLevel(logging.DEBUG)             # default log level
 
 # output program text-logo
-log.info("lmc.py - LMC Movie Catalogue  $Rev: 97 $ (c) by Uwe Mayer")
+log.info("lmc.py - LMC Movie Catalogue  $Rev: 101 $ (c) by Uwe Mayer")
 
 # load settings
 settings = Settings.Settings()
@@ -121,11 +121,12 @@ class LMCMain(LMCWidgetBase):
             pass                        # TODO: do abort
 
 
-        # private variables
+        # runtime variables
         self.__file = None              # no file opened so far
-
         self.lastFolder = pref['defaultPath']
-
+        self.recordCopy = None
+#        self.statusBar = self.statusBar()
+        
         # create logging
         self.log = logging.getLogger("LMCMain")
 
@@ -143,8 +144,7 @@ class LMCMain(LMCWidgetBase):
 
 
     #-- slot implementations ---------------------------------------------------
-    # connecting PYSIGNALs to the statusbar does not seem to work :(
-    # this this little wrapper
+    # wrapper with unified maximum delay
     def updateStatusBar(self, message, delay=5000):
         """updates status bar"""
         self.statusBar().message(message, delay)
@@ -367,8 +367,6 @@ class LMCMain(LMCWidgetBase):
         if (len(self.centralWidget()) > 0):
             self.__enableMovieDeleteAction()
 
-        self.connect( self.centralWidget().listViewRecord, PYSIGNAL("incSearchTextChanged"), self.updateStatusBar)
-
 
     def movieAdd(self):
         """adds a new movie record"""
@@ -442,7 +440,7 @@ class LMCMain(LMCWidgetBase):
         record['videoFormat'] = info.videoFormat
         record['audioFormat'] = info.audioFormat
         record['resolution'] = info.resolution
-        record['languages'] = info.languages
+#        record['languages'] = info.languages
         record['subtitles'] = info.subtitles
         record['videoBitrate'] = info.videoBitrate
         record['audioBitrate'] = info.audioBitrate
@@ -461,6 +459,10 @@ class LMCMain(LMCWidgetBase):
         
         self.centralWidget().setCurrentRecord(record)
 
+        # focus first field on AMCForm
+        self.centralWidget().form.focus("mediaLabel")
+
+
 
     def movieGetLocalCDFromFiles(self):
         """mount /unmount when getting information from a file"""
@@ -484,8 +486,7 @@ class LMCMain(LMCWidgetBase):
         else:
             self.log.info("Unmounting %s", pref['autoMountPoint'])
             os.system("umount %s &"%pref['autoMountPoint'])
-
-        
+       
 
     def movieGetLocalFromScript(self):
         """get information from a script"""
@@ -609,7 +610,52 @@ class LMCMain(LMCWidgetBase):
         if (new.has_key('picture')): 
             self.centralWidget().image.imageDecode()
                     
+        # focus first field on AMCForm
+        self.centralWidget().form.focus("mediaLabel")
+        
 
+    def onMovieCopy(self):
+        """copy current record"""
+        record = self.centralWidget().getCurrentRecord()
+        self.log.info("Copying record %s to clipboard", unicode(record['number']))
+        self.statusBar().message("Copying record %s to clipboard"%unicode(record['number']), 2000)
+        self.recordCopy = record        # copy reference to original
+
+        if (not self.moviePasteAction.isEnabled()):
+            self.connect(self.moviePasteAction, SIGNAL("activated()"), self.onMoviePaste)
+            self.moviePasteAction.setEnabled(True)
+
+            self.connect(self.toolPasteAction, SIGNAL("pressed()"), self.onMoviePaste)
+            self.toolPasteAction.setEnabled(True)
+        
+
+    def onMoviePaste(self):
+        """paste over current record"""
+        record = self.centralWidget().getCurrentRecord()
+
+        # if copied record == current record: paste as new
+        if (record == self.recordCopy):
+            self.log.info("Pasting to new record")
+            # prevent autoScanOnNew, autoScanAutoMountOnNew and autoScriptOnNew
+            a, b, c = pref['autoScanOnNew'], pref['autoScanAutoMountOnNew'], pref['autoScriptOnNew']
+            pref['autoScanOnNew'], pref['autoScanAutoMountOnNew'], pref['autoScriptOnNew'] = False, False, False
+            self.movieAdd()
+            record = self.centralWidget().getCurrentRecord()
+            pref['autoScanOnNew'], pref['autoScanAutoMountOnNew'], pref['autoScriptOnNew'] = a, b, c
+        
+        self.log.info("Pasting to record %s from clipboard", unicode(record['number']))
+        self.statusBar().message("Pasting to record %s from clipboard"%unicode(record['number']), 2000)
+
+        originalNumber = record['number']
+        record.update(deepcopy(self.recordCopy))
+        record['number'] = originalNumber
+
+        self.centralWidget().setCurrentRecord(record)
+        
+        if (pref['deepcopyOnCopy']):
+            self.log.debug("Creating deepcopy of image")
+            self.centralWidget().image.imageDecode()
+            
 
     #-- helper methods ---------------------------------------------------------
     def __querySaveOnDirty(self):
@@ -707,6 +753,15 @@ class LMCMain(LMCWidgetBase):
         self.toolAddAction.setEnabled(False)
         self.disconnect(self.toolAddAction, SIGNAL("pressed()"), self.movieAdd)
 
+        if (self.moviePasteAction.isEnabled()):
+            self.recordCopy = None
+            
+            self.moviePasteAction.setEnabled(False)
+            self.disconnect(self.moviePasteAction, SIGNAL("activated()"), self.onMoviePaste)
+
+            self.toolPasteAction.setEnabled(False)
+            self.disconnect(self.toolPasteAction, SIGNAL("pressed()"), self.onMoviePaste)
+
 
     def __enableMovieDeleteAction(self):
         """enables actions related to deleting a record"""
@@ -735,6 +790,14 @@ class LMCMain(LMCWidgetBase):
         self.connect(self.toolGetFromScriptAction, SIGNAL("pressed()"), self.movieGetLocalFromScript)
         self.toolGetFromScriptAction.setEnabled(True)
 
+        self.connect(self.centralWidget().listViewRecord, PYSIGNAL("incSearchTextChanged"), self.updateStatusBar)
+
+        self.connect(self.movieCopyAction, SIGNAL("activated()"), self.onMovieCopy)
+        self.movieCopyAction.setEnabled(True)
+
+        self.connect(self.toolCopyAction, SIGNAL("pressed()"), self.onMovieCopy)
+        self.toolCopyAction.setEnabled(True)
+
 
     def __disableMovieDeleteAction(self):
         """disables actions related to deleting a record"""
@@ -763,6 +826,15 @@ class LMCMain(LMCWidgetBase):
         self.toolGetFromScriptAction.setEnabled(False)
         self.disconnect(self.toolGetFromScriptAction, SIGNAL("pressed()"), self.movieGetLocalFromScript)
 
+        self.disconnect(self.centralWidget().listViewRecord, PYSIGNAL("incSearchTextChanged"), self.updateStatusBar)
+
+        self.movieCopyAction.setEnabled(False)
+        self.disconnect(self.movieCopyAction, SIGNAL("activated()"), self.onMovieCopy)
+
+        self.toolCopyAction.setEnabled(False)
+        self.disconnect(self.toolCopyAction, SIGNAL("pressed()"), self.onMovieCopy)
+
+        
         
 
 #-- main program ---------------------------------------------------------------
